
#ifndef __GLOBAL_TYPES_H__
#define __GLOBAL_TYPES_H__

#if (defined(_WIN32) || defined(_WIN64)) && !defined(__WIN__)
#define __WIN__
#endif

#ifndef __WIN__
#include <stdlib.h>
#include <sys/resource.h>
#endif

#ifndef __WIN__
typedef struct _RECT 
{ 
    int left; 
    int top; 
    int right; 
    int bottom; 
}RECT, *LPRECT;

typedef struct tagPOINT
{
    int  x;
    int  y;
}POINT, *LPPOINT;

#define __stdcall
#else
#define WIN32_LEAN_AND_MEAN 
#include <windows.h>
#endif

/**********************************************************************************************
* Character length                                                                 
**********************************************************************************************/
#define LEN_0									0
#define LEN_2									2
#define LEN_4									4
#define LEN_8   								8
#define LEN_10									10
#define LEN_16  								16
#define LEN_17  								17
#define LEN_20  								20
#define LEN_24  								24
#define LEN_32  								32
#define LEN_33  								33
#define LEN_36  								36
#define LEN_64  								64
#define LEN_65  								65
#define LEN_63  								63
#define LEN_128 								128
#define LEN_250 								250
#define LEN_256 								256
#define LEN_512 								512
#define LEN_300 								300
#define LEN_1024 								1024
#define LEN_1300 								1300 
/**********************************************************************************************/


/**********************************************************************************************
* Intelligent analysis of drawing area limits
**********************************************************************************************/
#define VCA_MAX_POLYGON_POINT_NUM				16	//The maximum number of points allowed per polygon
#define VCA_MAX_POLYGON_POINT_NUMEX				32	//Max Tripwire Points Number
#define VCA_MAX_POLYGON_NUM						25	//The maximum number of polygons allowed per VCA rule
#define MAX_AREA_NUM							4	//Max Area Number for 300w Leave Detect
/**********************************************************************************************/


/**********************************************************************************************
* The intelligent analysis information stored in the video file
**********************************************************************************************/
#define MAX_SAVE_TARGET_NUM  16
#define VCAINFO_SEARCHRULE_MIN					0
#define VCAINFO_SEARCHRULE_FRAME				(VCAINFO_SEARCHRULE_MIN+0)
#define VCAINFO_SEARCHRULE_POLYGON				(VCAINFO_SEARCHRULE_MIN+1)
#define VCAINFO_SEARCHRULE_TRIPWIRE				(VCAINFO_SEARCHRULE_MIN+2)
#define VCAINFO_SEARCHRULE_MAX					(VCAINFO_SEARCHRULE_MIN+3)
/**********************************************************************************************/


/**********************************************************************************************
* The intelligent analysis information stored in the video file
**********************************************************************************************/
#define SIP_CMD_SET_MIN							(2)
#define SIP_CMD_SET_ALARMCHANNEL				(SIP_CMD_SET_MIN+0)
#define SIP_CMD_SET_VIDEOCHANNEL				(SIP_CMD_SET_MIN+1)
#define SIP_CMD_SET_MAX							(SIP_CMD_SET_MIN+2)
/**********************************************************************************************/


/**********************************************************************************************
* Video Size                                                                      
**********************************************************************************************/
#define QCIF									0		//QCif 	176*144
#define HCIF									1		//HCif	352*144	
#define FCIF									2		//Cif	352*288	
#define HD1										3		//HD1	720*288
#define FD1										4		//D1	720*576
#define MD1										5		//MD1	720*288
#define QVGA									6		//QVGA	320x240
#define VGA										7		//VGA	640*480
#define HVGA									8		//HVGA	640*240
#define HD_720P									9		//720p	1280*720
#define HD_960P									10		//960P	1280*960
#define HD_200W									11		//200W	1600*1200
#define HD_1080P								12		//1080P	1920*1080
#define HD_QXGA									13		//QXGA	2048*1536

#define QHD										0x100	//QHD	960*540
#define VZ_960H									0x200	//960H	960*576
#define VZ_720_720								0x201	//		720*720
#define VZ_2MP									0x202	//2MP	1280*1280
#define VZ_3MP									0x203	//3MP	3072*1152
#define VZ_1440P								0x210	//1440P	2560*1440
#define VZ_4MP									0x220	//4MP	2592*1520
#define WUXGA									0x230	//WUXGA 1920*1200
#define HK_4MP									0x240	//4MP	2688*1520
#define VZ_FEC_4MP								0x250	//4MP	2048*2048
#define VZ_5MA									0x300	//5.0MP	2448*2048
#define VZ_5M									0x400	//5M(2)	2560*1920
#define VZ_5MB									0x410	//5M(3)	2592*1944
#define VZ_5MC									0x420	//5M(4)	2592*2048
#define VZ_5MD									0x430	//5M(5)	2528*2128
#define VZ_5ME									0x500	//5M	2560*2048
#define VZ_6M									0x600	//6M	2752*2208
#define VZ_6MA									0x610	//6M	3008*2008
#define VZ_6MB									0x620	//6M	3408*2008
#define VZ_FEC_6M								0x630	//FEC6M	2560*2560
#define VZ_7M									0x700	//7M	3392*2008
#define VZ_FEC_7M								0x700	//FEC7M	3072*2304
#define VZ_8MA									0x800	//8M	3840*2160
#define VZ_8MB									0x810	//8M	3264*2448
#define VZ_8MC									0x820	//8M	329682472
#define VZ_9M									0x900	//9M	3072*3072
#define VZ_12M									0x1200	//12M	4000*3072
/*********************************************************************************************/



/**********************************************************************************************
** User data information                                                                    
**********************************************************************************************/
#define GET_USERDATA_INFO_MIN                   (0)                           
#define GET_USERDATA_INFO_TIME					(GET_USERDATA_INFO_MIN )	//Get time information in user data
#define GET_USERDATA_INFO_OSD					(GET_USERDATA_INFO_MIN + 1)	//Get OSD information in user data
#define GET_USERDATA_INFO_GPS                   (GET_USERDATA_INFO_MIN + 2)	//Get GPS information in user data
#define GET_USERDATA_INFO_VCA                   (GET_USERDATA_INFO_MIN + 3)	//Get VCA information in user data
#define GET_USERDATA_INFO_USER_DEFINE           (GET_USERDATA_INFO_MIN + 4)	// Get the custom information in the user data
#define GET_USERDATA_INFO_VITAL_SIGN_DATA		(GET_USERDATA_INFO_MIN + 5)	//Get vital signs information in user data
#define GET_USERDATA_INFO_DEMOGRAPHICS			(GET_USERDATA_INFO_MIN + 6)	// Get the count in the user data
#define GET_USERDATA_INFO_LPR					(GET_USERDATA_INFO_MIN + 7)	//Get license plate identification information in user data
#define GET_USERDATA_INFO_OSD_EX				(GET_USERDATA_INFO_MIN + 8)	//Get OSD information in user data
#define GET_USERDATA_INFO_LDC					(GET_USERDATA_INFO_MIN + 9)	//Obtain distortion correction information in user data
#define GET_USERDATA_INFO_ZF                    (GET_USERDATA_INFO_MIN + 10)//ZF focus mark
#define GET_USERDATA_INFO_MAX                   (GET_USERDATA_INFO_MIN + 11)
#define GET_ALL_USERDATA_INFO					(0xFF)
#define GET_USERDATA_END						(0xFFFFFF) 
/**********************************************************************************************/


/* License plate string length */                                                        
#define LPR_PLATE_STR_LEN						11
#define MAX_OUTPUT_LPR_NUM						10

/* * License Plate Color * */                                                                
#define LPR_PLATE_COLOR_WHITE					0	// White card
#define LPR_PLATE_COLOR_YELLOW					1	// Yellow card
#define LPR_PLATE_COLOR_BLUE					2	// Blue card
#define LPR_PLATE_COLOR_BLACK					3	// Black card
#define LPR_PLATE_COLOR_GREEN					4	// Green card
#define LPR_PLATE_COLOR_UNKNOWN					99	// Other

/* Currently Supported Models */
#define LPR_VT_UNKOWN							0	//Unknown model
#define LPR_VT_BUS								1	//Buses and coaches
#define LPR_VT_CAR								2	//Cars
#define LPR_VT_TRUCK							3	//Trucks, including large and small goods
#define LPR_VT_VAN								4	//The van
#define LPR_VT_BIG_TRUCK						5	//large trucks
#define LPR_VT_SMALL_TRUCK						6	//A minivan
#define LPR_VT_TWO_THREE_WHEELER				7	//Two or three wheels
#define LPR_VT_PERSON							8	//Pedestrians	
#define LPR_VT_SUV								9	//SUV
#define LPR_VT_MID_BUS							10	//Medium Buses
#define LPR_VT_BGS								14	//Background detection detected
#define LPR_VT_OTHER							15	// Other models
/**********************************************************************************************/

/* Car Type  */                                                                  
#define LPR_PLATE_TYPE_UNKOWN			   		0	// Unknown
#define LPR_PLATE_TYPE_BIG		               	1	// Large car
#define LPR_PLATE_TYPE_SMALL	               	2	// Small cars
#define LPR_PLATE_TYPE_AMBASSADOR				3	// Embassy vehicle
#define LPR_PLATE_YTPE_COUSULATE          		4	// Consular car
#define LPR_PLATE_YTPE_OVERSEAS					5	// Outside the car
#define LPR_PLATE_YTPE_FOREIGN					6	// Foreign cars
#define LPR_PLATE_YTPE_TWO_THREE_WHEELES		7	//  Two and three-wheeled motorcycles
#define LPR_PLATE_TYPE_MOTOR					8	// Light motorcycle
#define LPR_PLATE_TYPE_MOTOR_AMBASSADOR			9	// mbassy Motorcycle
#define LPR_PLATE_TYPE_MOTOR_COUSULATE			10	// Consulate Motorcycle
#define LPR_PLATE_TYPE_MOTOR_OVERSEAS			11	// Foreign motorcycles
#define LPR_PLATE_TYPE_MOTOR_FOREIGN			12	// Foreign motorcycles
#define LPR_PLATE_TYPE_FARM						13	// Farm vehicles
#define LPR_PLATE_TYPE_TRACTOR					14	// Tractor
#define LPR_PLATE_TYPE_GUA						15	// "gua" license plate
#define LPR_PLATE_TYPE_COACH					16	// Coach Car
#define LPR_PLATE_TYPE_COACH_MOTOR				17	// Coach Motorcycle
#define LPR_PLATE_TYPE_TRIAL					18	// Test the car
#define LPR_PLATE_TYPE_TRIAL_MOTOR				19	// Test motorcycles
#define LPR_PLATE_TYPE_LIAOTEMP_ENTER			20	// Temporary entry vehicle
#define LPR_PLATE_TYPE_LIAOTEMP_MOTOR_ENTER		21	// Temporary Entry Motorcycle
#define LPR_PLATE_TYPE_LIAOTEMP					22	// Temporary travel vehicle
#define LPR_PLATE_TYPE_POLICE					23  // Police car
#define LPR_PLATE_TYPE_POLICE_MOTOR				24  // Police motorcycle
#define LPR_PLATE_TYPE_BIKE						99	// Electric bicycles
/**********************************************************************************************/

/* Car Logo  */                                                                  
#define LPR_LOGO_UNKNOWN						0	// Unknown
#define LPR_LOGO_VOLKSWAGEN						1	//Volkswagen(Volkswagen / Volkswagen)
#define LPR_LOGO_AUDI							2	//Audi
#define LPR_LOGO_TOYOTA							3	//Toyota
#define LPR_LOGO_HONDA							4	//Honda
#define LPR_LOGO_BENZ							5	//Mercedes-Benz
#define LPR_LOGO_CHEVROLET						6	//Chevrolet
#define LPR_LOGO_CHEERY							7	//Chery AutomobileChery Automobile Corporation
#define LPR_LOGO_BUICK							8	//Buick
#define LPR_LOGO_GREATWALL						9	//GreatWall
#define LPR_LOGO_HYUNDAI						10	//Hyundai
#define LPR_LOGO_NISSAN							11	//Nissan
#define LPR_LOGO_FORD							12	//Ford
#define LPR_LOGO_BMW							13	//BMW
#define LPR_LOGO_CITROEN						14	//Citroen
#define LPR_LOGO_KIA							15	//Kia 
#define LPR_LOGO_SUZUKI							16	//Suzuki 
#define LPR_LOGO_MAZDA							17	//Mazda 
#define LPR_LOGO_BUILDYD						18	// BYD  build your dreams
#define LPR_LOGO_PEUGEOT						20	//Peugeot 	
#define LPR_LOGO_CCAG							21	//Chongqing Changan
#define LPR_LOGO_JAC          					22	//Chongqing Changan
#define LPR_LOGO_ZHONGHUA						23	//China
#define LPR_LOGO_SKODA							24	//Skoda
#define LPR_LOGO_HAIMA							25	//Hippocampus
#define LPR_LOGO_XIALI							26	//Xiali
#define LPR_LOGO_SGMW							27	//Shanghai GM WulingSGMW
#define LPR_LOGO_DONGFENG						28	//DongFeng
#define LPR_LOGO_HAFEI							29	//Shanghai GM Wuling
#define LPR_LOGO_FAWCAR							30	//First Automobile Works(FAW)
#define LPR_LOGO_BAOJUN							31	//Po Chun
#define LPR_LOGO_EMGRAND						25	//Imperial
#define LPR_LOGO_MG								27	//MG
#define LPR_LOGO_SOUTHEAST						34	//Southeast
#define LPR_LOGO_CROWN							35	//Southeast
#define LPR_LOGO_JINBEI							36	//he Gold Cup
#define LPR_LOGO_MITSUBISHI						37	//Mitsubishi 	
#define LPR_LOGO_ROEWE							38	// Roewe
#define LPR_LOGO_GEELY							39	//Geely
#define LPR_LOGO_ENGLONCAR						40	//England
#define LPR_LOGO_GLEAGLE						41	//Global Hawk
#define LPR_LOGO_SAIBAO							42	//Hafei Leopard
#define LPR_LOGO_CHANGFENG						43	//Changfeng
#define LPR_LOGO_WINWON							44	//Vivien
#define LPR_LOGO_BEIJING						45	// Beijing
#define LPR_LOGO_XINTIAN						46	//The new Kay
#define LPR_LOGO_JIAO							47	//Guangzhou Automobile Gio
#define LPR_LOGO_MASERRATI						48	//Maserati
#define LPR_LOGO_ROVER           				49	//Rover
#define LPR_LOGO_AUSTIN          				50	//Austin
#define LPR_LOGO_MARX							51	//Markus
#define LPR_LOGO_DAOQI							52	//Chrysler Dodge
#define LPR_LOGO_SHUNFENG 53 // Chrysler downwind
#define LPR_LOGO_GENERAL 54 // General Pontiac
#define LPR_LOGO_JAGUAR 55 // Jaguar
#define LPR_LOGO_OZZY 56 // Ozzy dawn
#define LPR_LOGO_ALPHA 57 // Alpha
#define LPR_LOGO_LAMBORGHINI 58 // Lamborghini
#define LPR_LOGO_BUGATTI 59 // Bugatti
#define LPR_LOGO_LINCOLN 60 // Lincoln
#define LPR_LOGO_FETTARI 61 // Ferrari
#define LPR_LOGO_CHANGHE 62 // Changhe
#define LPR_LOGO_FIAT 63 // Fiat
#define LPR_LOGO_FUKUDA           				64	//Fukuda
#define LPR_LOGO_ACURA 65 // Acura
#define LPR_LOGO_LOTUS 66 // Lotus
#define LPR_LOGO_MAPLE 67 // Maple
#define LPR_LOGO_REDFLAG 68 // Red flag
#define LPR_LOGO_RUIQI              			69	//Rui Qi
#define LPR_LOGO_PENTIUM         				70	//Pentium
#define LPR_LOGO_WEILIN             			71	//Wei Lin
#define LPR_LOGO_ZHONGTAI        				72	//Chung Tai
#define LPR_LOGO_LIFAN              			73	//Lifan
#define LPR_LOGO_NJJEEP							74	//Beijing Jeep
#define LPR_LOGO_ZHONGXIN						75	// ZTE
#define LPR_LOGO_KAIRUI							76	// Kai Rui
#define LPR_LOGO_LANDROVER 77 // Land Rover
#define LPR_LOGO_MCG 78 // Maybach
#define LPR_LOGO_LEINUO 79 // Renault
#define LPR_LOGO_OPEL 80 // Opel
#define LPR_LOGO_EILDHORSE 81 // Mustang
#define LPR_LOGO_JEEP 82 // JEEP
#define LPR_LOGO_IVECO 83 // Iveco
#define LPR_LOGO_INFINITI 84 // Infiniti
#define LPR_LOGO_SUBARU 85 // Subaru
#define LPR_LOGO_ASTON 86 // Aston Martin
#define LPR_LOGO_ANKAI							87	//Ankai
#define LPR_LOGO_PARSCHE 88 // Porsche
#define LPR_LOGO_BENTLEY 89 // Bentley
#define LPR_LOGO_FODDY 90 // Fuddy
#define LPR_LOGO_KAITENG            			91	//Qi steam Kai Teng
#define LPR_LOGO_GEMS               			92	//Jim
#define LPR_LOGO_QOROS							93	// view to
#define LPR_LOGO_TRUMPCHI           			94	// wide steam Qi
#define LPR_LOGO_SSANGYONG						95	//Ssangyong
#define LPR_LOGO_HAIGER 96 // Hagrid
#define LPR_LOGO_HUMMER 97 // Hummer
#define LPR_LOGO_HUATAI 98 // Huatai
#define LPR_LOGO_HUANGHAI 99 // Yellow Sea
#define LPR_LOGO_KOWLOON 100 // Kowloon
#define LPR_LOGO_IDEA 101 // Ideas
#define LPR_LOGO_SMART 102 // SMART
#define LPR_LOGO_TERRAL 103 // landwind
#define LPR_LOGO_NAZHIJIE           			104	//Na Zhijie
#define LPR_LOGO_ELEGANZA						105	//Oulang
#define LPR_LOGO_KAICHEN						106	//Kai Chen
#define LPR_LOGO_ORHER							999	// Other
/**********************************************************************************************/



/* Currently supported illegal types */
#define LPR_IT_UNKOWN 0 // Unknown type
#define LPR_IT_NOSAFETYBELT 1 // Do not wear seat belts
#define LPR_IT_PHONE 2 // Call
#define LPR_IT_NOPRESSLINE 4 // There is no pressure line, illegal lane change
#define LPR_IT_NOILL							8	// no offense, police do not capture illegal records
/**********************************************************************************************/

/* struct of vca */                                                                 
typedef struct tagvca_TRect
{
	unsigned short	usLeft;
	unsigned short	usTop;
	unsigned short	usRight;
	unsigned short	usBottom;
} vca_TRect, *pvca_TRect;

typedef struct tagvca_TTargetInfo
{
	vca_TRect		rect;
	unsigned short	usType;
	unsigned short	usVelocity;
	unsigned short	usDirection;
	unsigned short	id;	
} vca_TTargetInfo, *pvca_TTargetInfo;

typedef struct tagvca_TTargetSet
{
	unsigned short	usCount;
	vca_TTargetInfo	targets[MAX_SAVE_TARGET_NUM]; 
} vca_TTargetSet, *pvca_TTargetSet;

//Used to store the number of statistical results
typedef struct tagTvca_cpcInfo
{
	short 			sCountIn;
	short 			sCountOut;
} Tvca_cpcInfo, *pTvca_cpcInfo;

typedef struct tagTvca_CpcData
{
	Tvca_cpcInfo 	tCpcInfo;			//Statistical result
	vca_TTargetSet	tVCATarget;			//Destination location
} Tvca_CpcData, *pTvca_CpcData;

typedef struct tagTvca_RGB
{
	unsigned char 	ucR;
	unsigned char 	ucG;
	unsigned char 	ucB;
} Tvca_RGB, *pTvca_RGB;

typedef struct tagITS_vca_TRect
{
	int				iTop;
	int				iBottom;
	int				iLeft;
	int				iRight;
} ITS_vca_TRect, *pITS_vca_TRect;

typedef struct tagTvca_LPRInfo
{
	Tvca_RGB		stCarColor;				//Body color
	int				iPlateColor;			//license plate color
	int      		iCarType;				//vehicle type
	int	      		iPlateType;				//License plate type
	int				iBrandType;				//The type of the cursor
	int				iIllgalType;			//Illegal type
	ITS_vca_TRect	stRectPlate;			//License plate position rectangle
	ITS_vca_TRect	stRectFace;				//face rectangle
	ITS_vca_TRect	stRectLogo;				//vehicle coordinates rectangular
	char			cPlateRec[LPR_PLATE_STR_LEN];// license plate number
	int				iHeadTail;				//front or rear: 0 unknown, 1 front, 2 rear
	ITS_vca_TRect	stRectCopilotFace;		//co-pilot face coordinate rectangle
	ITS_vca_TRect	stCarRegion;			//vehicle profile
} Tvca_LPRInfo, *pTvca_LPRInfo;

typedef struct tagTvca_LPRData
{
	int				iNumOutputs;			//output the number of results
	int				iSize;					//Input Parameters: Enter a single Tvca_LPRInfo structure size
	Tvca_LPRInfo	stOutputs[MAX_OUTPUT_LPR_NUM];//Can output multiple results
} Tvca_LPRData, *pTvca_LPRData;

typedef struct tagZFUserMarkPara
{
	int m_iUserMarkType;	//type, 0-no mark, 1-focus mark, 2-audio mark(the last two parameters are valid)
	int m_iVideoChan;		//video channel
	int m_iAudioTag;		//0-no audio(audio end), 1-has audio(audio start)
} ZFUserMarkPara, *pZFUserMarkPara;

/**********************************************************************************************/


typedef struct _tagCurrentFrameInfo
{
	unsigned int	uiSize;					//size of struct
	unsigned int	uiFrameNO;				//frame index
	unsigned int	uiFrameType;			//frame type:I=0, P=1,B=2
	unsigned int	uiTimeStamp;			//time stamp 
} CurrentFrameInfo, *pCurrentFrameInfo;




/* Auto Test  */                                                                 
#define AUTOTEST_PARAM_SIZE			5
#define AUTOTEST_STRING_SIZE		65
typedef struct _strAutoTest_Para
{
	int				iTestParam[AUTOTEST_PARAM_SIZE];
	char			cTestParam[AUTOTEST_STRING_SIZE];
	char			cTestParam1[AUTOTEST_STRING_SIZE];
}strAutoTest_Para;
/**********************************************************************************************/

typedef struct	//custom common information
{
	char			m_cParam1[LEN_64];
	char			m_cParam2[LEN_64];
	char			m_cParam3[LEN_64];
	char			m_cParam4[LEN_64];
	char    		m_cParam5[LEN_64];
	char    		m_cParam6[LEN_64];
	char    		m_cParam7[LEN_64];
	char    		m_cParam8[LEN_64];
	char    		m_cParam9[LEN_64];
	char    		m_cParam10[LEN_64];
	char    		m_cParam11[LEN_64];
	char    		m_cParam12[LEN_64];
	char    		m_cParam13[LEN_64];
	char    		m_cParam14[LEN_64];
	char    		m_cParam15[LEN_64];
	char    		m_cParam16[LEN_64];
	char    		m_cParam17[LEN_64];
	char    		m_cParam18[LEN_64];
	char    		m_cParam19[LEN_64];
	char    		m_cParam20[LEN_64];
}DZ_INFO_PARAM, *PDZ_INFO_PARAM;

/* NVSSDK, PlaySDKM4 Common structure  */                                                                  
typedef struct
{
    unsigned short  m_ulMajorVersion;
    unsigned short  m_ulMinorVersion;
    unsigned short  m_ulBuilder;
    char*           m_cVerInfo;
}SDK_VERSION;

#define MAX_MONITOR_DESCLEN			512
typedef struct MONITOR_INFO					
{
	char			cDriverDesc[MAX_MONITOR_DESCLEN];
	char			cDriverName[MAX_MONITOR_DESCLEN];	
	RECT			rect;
}MONITOR_INFO, *PMONITOR_INFO;

//Callback YUV data
typedef struct tagDecAVInfo
{
	int				iType;				//0: video 1: audio
	int				iFormat;
	int				iWidth;
	int				iHeight;
	const unsigned char *pucData;
	int iDataLen;
}DecAVInfo, *PDecAVInfo;

typedef struct tagDecVideoOtherInfo
{
	unsigned int uiTimeStamp;
	int	iFrameRate;
	int iReserved;
	int iUserPutData;
}DecVideoOtherInfo;

typedef struct tagAudioSampleValue
{ 
	int			iChannel;				//audio channel num                
	int			iMaxSampleValue1;		//audio channel 1 max sample value range[-300~300]
	int			iMinSampleValue1;		//audio channel 1 min sample value
	int			iIsMaxBeforeMin1;		//whether audio channel 1 max sample value appear before  min sample value
	int			iMaxSampleValue2;		//audio channel 2 max sample value 
	int			iMinSampleValue2;		//audio channel 2 min sample value
	int			iIsMaxBeforeMin2;		//whether audio channel 2 max sample value appear before  min sample value
}AudioSampleValue, *PAudioSampleValue;

typedef struct tagDecAudioOtherInfo
{
	unsigned int uiTimeStamp;
	int	iFrameRate;
	AudioSampleValue* ptAudioSampleValue;//audio sample value
	int iAudioSampleRate;//audio sample rate
	int iAudioChannelNum; //audio channel num
}DecAudioOtherInfo;

typedef struct tagDecAVInfoEx
{
	DecAVInfo 		m_pInfo;
	//judge below value type with m_iOtherInfoSize 1:TimeStamp(unsigned int), 2:FrameRate(int)
	int				m_iOtherInfoSize;		
	void*	m_pvOtherInfo;  //DecVideoOtherInfo* or DecAudioOtherInfo*

}DecAVInfoEx, *PDecAVInfoEx;

typedef struct tagPSPACK_INFO
{
	unsigned long	nWidth;
	unsigned long	nHeight;
	unsigned long	nStamp;
	unsigned long	nType;
	unsigned long	nFrameRate;
	unsigned long	nReserved;
} PSPACK_INFO, *PPSPACK_INFO;

typedef struct
{
	unsigned long	nWidth;				//Video width, audio data is 0
	unsigned long	nHeight;			//Video height, audio data is 0
	unsigned long	nStamp;				//Time stamp(ms)
	unsigned long	nType;				//Audio typeT_AUDIO8,T_YUV420
	unsigned long	nFrameRate;			//Frame rate
	unsigned long	nReserved;			//reserve
}FRAME_INFO;
/*********************W*************************************************************************/

/*vital signs instrument information collect   */                                                               
#define VITAL_SIGN_HR		1			//heart rate
#define VITAL_SIGN_BO		2			//blood oxygen concentration
#define VITAL_SIGN_BP		3			//blood pressure
#define MAX_POINTS_NUM		512
typedef struct __tagVitalSignData 
{
	char			cVersion;			//treaty version
	char			cType;				//vital signs instrument information type,1heart rate 2blood oxygen concentration 3blood pressure
	char			cMonFlg;			//1:normal 2:Upper limit 3Ultra-low limit 4:probe off 5:device offline    
	char			iOscilloGramSeqID;	//1ʼĵδ123Ѫһʹ1
	int				iMonVal[4];			//ʵʱֵ, Ѫѹ3,SYS DIA PRδţȣԭֵ100;
	int				iGramRate;			//1sжٸ
	int				iSizeType;			//ƵӲС  1: 2 3С
	int				iXPosition;			//ƵϽ(0,0)Ժ(ֱ)
	int				iYPosition;			//ƵϽ(0,0)(ֱ)
	int				iPointLen;
	unsigned char	cPointValue[MAX_POINTS_NUM];
} VitalSignData, *pVitalSignData;

//frame absoluteTime time parameter
#ifndef IOS
typedef struct tagAbsoluteTime
{
	unsigned short	iYear;				//Year
	unsigned short	iMonth;				//Month
	unsigned short	iDay;				//Day
	unsigned short	iHour;				//Hour
	unsigned short	iMinute;			//Minute
	unsigned short	iSecond;			//Second
	unsigned int	uiTime;
} AbsoluteTime, *pAbsoluteTime;
#else
typedef struct __SAbsoluteTime
{
    unsigned short	 iYear;				//Year
    unsigned short	 iMonth;				//Month
    unsigned short	 iDay;				//Day
    unsigned short	 iHour;				//Hour
    unsigned short	 iMinute;			//Minute
    unsigned short	 iSecond;			//Second
    unsigned int uiTime;
} AbsoluteTimeIOS, *pAbsoluteTimeIOS;
#endif
typedef struct __tagTStreamData
{
	int				iSize;
	char			cStreamData[64];
	int				iStreamLen;
} TStreamData, *PTStreamData;

#define OSD_TYPE_CHANNELNAME		1
#define OSD_TYPE_TIMEDATE			2
#define OSD_TYPE_LOGOCOLOR			3
#define OSD_TYPE_ADDITIONALCHAR		4
#define OSD_TYPE_ITS				5
#define OSD_TYPE_ITS_COMBINEPIC		6
typedef struct
{
	unsigned int		uiOSDType;			//1Channel nameText 2Time and date 3:logo color 4append osd  characters 5:traffic ipc exclusive use  6traffic ipc combining picture
	unsigned int		uiOSDBGColor;		// back color, total 32 bit low 24 bit means color rgb,bgr in figure0x00BBGGRRHigh 8bit useless
	unsigned int		uiOSDColor;			//text color
	unsigned int		uiOSDSize;			// 15,total 32 bit low 16 bit means Height High 16 bit means width,0-Auto
	unsigned int		uiOSDDiaphaneity;	//diaphaneity  range0100
	unsigned int		uiOSDPostionX;		//abscissa or location number
	//1if uiOSDPostionY equal to 0 uiOSDPostionX means location number range015
	//2if uiOSDPostionY greater t 0uiOSDPostionX and uiOSDPostionY combine a point means osd postionuiOSDPostionY must plus 1 eg: want set(16,0)network treaty send161ipc actual set160
	unsigned int		uiOSDPostionY;		
	int					ilength;
	char				cText[LEN_256];		//osd text content
} osd_TOSDSet;

typedef struct
{
	double f64Fx;
	double f64Fy;
	double f64Cx;
	double f64Cy;
	double af64K[12];
} UdtCameraPara;

typedef struct
{
	int					iType;		//0-reserveed 1-warehouse camera 2-fish camera
	int					ilength;
	UdtCameraPara		tUdtCameraPara;
} osd_TLDCSet;
/**********************************************************************************************/

typedef struct __tagExtraInfo
{
	int				m_iInfoLen;
	void*			m_pvExtInfo;	
}FRAME_EXT_INFO, *LPFRAME_EXT_INFO;



//Schedle time
typedef struct
{
	unsigned short  iStartHour;
	unsigned short  iStartMin;
	unsigned short  iStopHour;
	unsigned short  iStopMin;
	unsigned short  iRecordMode;			//iEnable;
}NVS_SCHEDTIME,*PNVS_SCHEDTIME;

typedef struct
{
	unsigned short  m_u16Brightness;
	unsigned short  m_u16Hue;
	unsigned short  m_u16Contrast;
	unsigned short  m_u16Saturation;
	NVS_SCHEDTIME strctTempletTime;
}STR_VideoParam;

//Record time parameter
typedef struct
{
	unsigned short iYear;   /* Year */
	unsigned short iMonth;  /* Month */
	unsigned short iDay;    /* Day */
	unsigned short iHour;   /* Hour */
	unsigned short iMinute; /* Minute */
	unsigned short iSecond; /* Second */
} NVS_FILE_TIME,*PNVS_FILE_TIME;

#define TYPE_NVS_T          0     //T NVS
#define TYPE_KEYBOARD       1     //Net keyboard
#define TYPE_CTL_ALLOTER    2     //Control code distributor
#define TYPE_ALARMHOST      3     //Network alarm host
#define TYPE_NVS_S          4     //S NVS
#define TYPE_MATRIX         5     //Matrix
#define TYPE_NET_PU         6     //Network Front-end device
#define TYPE_NET_GURAD      7     //Net Entrance Gurad
#define TYPE_PC_DVR         8     //PC DVR
#define TYPE_S_DECODER      9     //S Decoder
#define TYPE_NVS_TPLUS      10    //TPLUS NVS
#define TYPE_WIH_S          11    //Unattended host
#define TYPE_EMBED_DVR      12    //embedded DVR
#define TYPE_SMS_200        13    //Linux stream media host
#define TYPE_ALARM_HOST42   14    //network alarm host
#define TYPE_TC_T820GE      15    //external trigger intersection camera
#define TYPE_TC_T860GE      16    //pure video intersection camera
#define TYPE_TC_T890GE      17    //external trigger ptz
#define TYPE_TC_HDC         18    //HD camera   
#define TYPE_ONVIF          19    //Onvif device 

/**********************************************************************************************
* public notify                                                            
**********************************************************************************************/
#ifndef __WIN__
typedef void (*pfCBGetDecAV)(int _iID, const DecAVInfo* _pDecAVInfo, void* _iUser);
#endif

typedef void (__stdcall *DEVUSERDATA_NOTIFY)(unsigned int _uiID, int _iType, void* _pvData
			 , int _iDataLen, CurrentFrameInfo* _ptInfo, void* _pvUdata);

//video and audio date after decoding
typedef void (*DECYUV_NOTIFY_V4)(unsigned int _ulID,unsigned char *_cData, int _iLen, 
								 const FRAME_INFO *_pFrameInfo, void* _iUser);

typedef int  (*PSPACK_NOTIFY)(int _iPlayerID, unsigned char* _ucData, int _iSize, 
							  PSPACK_INFO* _pPsPackInfo, void* _pContext);
/**********************************************************************************************/

#define	ENABLE_LAST_FRAME   0x13001		//keep last frame when disconnect
#define ENABLE_PREFERENCE   0x13002		//preview preference set
#ifndef MAX_NAME_LEN
#define MAX_NAME_LEN 64
#endif
#define FILE_COUNT			16	//max support num
#define FILE_COUNT_EX		8	

typedef struct tagExportConfig
{
	int		iSize;		    //Size of the structure,must be initialized before used
	int		iCount;		    //input num		      
	char   	cFileList[FILE_COUNT][MAX_NAME_LEN];	//file list
	char    cFileOut[LEN_128];  //out put file
	char   	cFileListEx[FILE_COUNT_EX][MAX_NAME_LEN];	//file list
} ExportConfig  ,*PExportConfig;

typedef int RAWFRAMETYPE;
#define VI_FRAME 0
#define VP_FRAME 1
#define AUDIO_FRAME 5

#define RAW_VIDEO_H264		1
#define RAW_VIDEO_MPEG4		2
#define RAW_VIDEO_MJPEG		41
#define RAW_VIDEO_H265		23

#define RAW_AUDIO_G711_A	0x01
#define RAW_AUDIO_G711_U	0x02
#define RAW_AUDIO_ADPCM_A	0x03
#define RAW_AUDIO_AAC		0x16

typedef struct
{
	unsigned int nWidth;    //Video width, audio data is 0
	unsigned int nHeight;   //Video height, audio data is 0
	unsigned int nStamp;    //Time stamp(ms)
	unsigned int nType;     //RAWFRAMETYPE, I Frame:0,P Frame:1,B Frame:2,Audio:5
	unsigned int nEnCoder;  //Audio or Video encoder(Video,0:H263,1:H264, 2:MP4. Audio:0,G711_A:0x01,G711_U:0x02,ADPCM_A:0x03,G726:0x04)
	unsigned int nFrameRate;//Frame rate
	unsigned int nAbsStamp; //Absolute Time(s)
	unsigned char ucBitsPerSample;// bit per sample [8/16/24] default 16
	unsigned int uiSamplesPerSec;// Samples Per Secdefault 8000
}RAWFRAME_INFO;

//Not decode the standard data before the pure h264 data
typedef void (__stdcall *RAWFRAME_NOTIFY)(unsigned int _ulID,unsigned char* _cData,int _iLen, RAWFRAME_INFO *_pRawFrameInfo, void* _iUser);

#define RAW_NOTIFY_ALLOW_DECODE		0
#define RAW_NOTIFY_FORBID_DECODE	1
typedef struct _tagRawFrameNotifyInfo
{
	RAWFRAME_NOTIFY pcbkRawFrameNotify;		//raw data notify with play control
	void*			pUserData;
	int				iForbidDecodeEnable;	//whether need to play     0-play 1-no need decode and play
}RawFrameNotifyInfo, *pRawFrameNotifyInfo;

#endif
